@@ -1,5 +1,5 @@
 re_estimator <-
-function (model, div, ages, GRAD=NULL, cats=NULL, breakpoint=NULL, domain=NULL, p_starting=NULL, parallel=FALSE, cores=NULL, absolute=TRUE) {
+function (model, div, ages, me1= NULL, me2 = NULL, GRAD=NULL, cats=NULL, breakpoint=NULL, domain=NULL, p_starting=NULL, parallel=FALSE, cores=NULL, absolute=TRUE) {
   
   if(model %in% c("BM_null", "OU_null", "BM_linear", "OU_linear", "OU_linear_sig", 
     "DA_null", "DA_linear", "DA_wt", "DA_bp", "DA_wt_linear", "DA_bp_linear", "DA_cat") == FALSE) {
